@@ -1,7 +1,7 @@
 
 from __future__ import division, print_function
 
-from os.path import join, exists
+from os.path import join, exists, splitext
 from os import path
 
 from Bio import SeqIO
@@ -24,6 +24,14 @@ class Lazyseq(object):
         self._seqpath = seqpath
 
     def load(self):
+        _, ext = splitext(self._seqpath)
+        if ext in ('.gb',):
+            filetype = 'genbank'
+        elif ext in ('.fa', '.faa', '.fna'):
+            filetype = 'fasta'
+        else:
+            msg = "reference has an unknown file type extension '%s'" % ext
+            raise ValueError(msg)
         with open(self._seqpath) as fh:
-            record = SeqIO.read(fh, 'fasta')
+            record = SeqIO.read(fh, filetype)
         return record
